==> vtigercrm-5.3.0p0.tgz: modules/Project/language/es_mx.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ************************************************************************************/
$mod_strings = Array(

  	'LBL_MODULE_NAME'=>'Proyectos',
  	'LBL_MODULE_TITLE'=>'Proyectos',
    'LBL_NEW_PROJECT'=>'Nuevo Proyecto',
    'LBL_PROJECTS'=>'Proyectos',
    'LBL_PROJECT'=>'Proyecto',
	'projectname' => 'Nombre Proyecto',
    'projects' => 'Proyectos',
    'project' => 'Proyectos',
    //added this to translate the module name in the main app menu
    'Project'=>'Proyectos',
    //
    'SINGLE_Project' => 'Proyecto',
    'LBL_CUSTOM_INFORMATION' => 'Información Personalizada',
    'LBL_PROJECT_INFORMATION' => 'Información de Proyecto',
    'LBL_DESCRIPTION_INFORMATION' => 'Descripción',
  
    'projectid' => 'ID Proyecto',  
    'Project ID'=>'ID Proyecto',
    'Assigned To' => 'Asignado a',
    'Start Date' => 'Fecha inicio',
    'Target End Date' => 'Fecha fin prevista',
    'Actual End Date' => 'Fecha fin real',
    'Status'=>'Estado',
    'Type'=>'Tipo',
    'Target Budget'=>'Presupuesto Inicial',
    'Project Url'=>'URL Proyecto',
    'Priority'=>'Prioridad Proyecto',
    'Progress'=>'Progreso',
    'Related To' => 'Relacionado con',
    'administrative' => 'administrativo',
    'operative' => 'operativo',
    'other' => 'otro',
    'low' => 'baja',
    'normal' => 'normal',
    'high' => 'alta',
    'prospecting' => 'Buscando',
    'in progress' => 'En progreso',
    'initiated' => 'Iniciado',
    'on hold' => 'En espera',
    'archived' => 'Archivado',
    'completed' => 'Finalizado',
    'delivered'=>'Entregado',
    'Created Time' => 'Fecha Creación',
    'Modified Time' => 'Fecha Modificación',
    'Description' => 'Descripción',
    'description' => 'Descripción',
    '--none--' => '--ninguno--',
    'Deadline' => 'Entrega',
    'Operation' => 'Actividad',
    'Project Name' => 'Nombre Proyecto',
    'LBL_RELATED_PROJECT_TASKS' => 'Actividades',
    'LBL_RELATED_PROJECT_MILESTONES' => 'Hitos',

	'Charts' => 'Gráficos',
	'LBL_PROGRESS_CHART' => 'Gráfico Progreso',
	'Project No' => 'Nº Proyecto',

	'Project Milestones' => 'Hitos Proyecto',
	'Project Tasks' => 'Actividades Proyecto',
	'Project Team' => 'Equipo Proyecto',
);

?>

==> vtigercrm-5.4.0.tgz: modules/Project/language/es_mx.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 * 
 * ***********************************************************
*  Module       : Project
*  Language     : ES Spanish
*  Version      : vt5.4.0
*  Created Date : 2012-02-27
*  Author       : Odin Consultores S de RL de CV
*  License      : MPL 1.1
 ************************************************************************************/
$mod_strings = Array(

  	'LBL_MODULE_NAME'=>'Proyectos',
  	'LBL_MODULE_TITLE'=>'Proyectos',
    'LBL_NEW_PROJECT'=>'Nuevo Proyecto',
    'LBL_PROJECTS'=>'Proyectos',
    'LBL_PROJECT'=>'Proyecto',
	'projectname' => 'Nombre Proyecto',
    'projects' => 'Proyectos',
    'project' => 'Proyectos',
    //added this to translate the module name in the main app menu
    'Project'=>'Proyectos',
    //
    'SINGLE_Project' => 'Proyecto',
    'LBL_CUSTOM_INFORMATION' => 'Información Personalizada',
    'LBL_PROJECT_INFORMATION' => 'Información de Proyecto',
    'LBL_DESCRIPTION_INFORMATION' => 'Descripción',
  
    'projectid' => 'ID Proyecto',  
    'Project ID'=>'ID Proyecto',
    'Assigned To' => 'Asignado a',
    'Start Date' => 'Fecha inicio',
    'Target End Date' => 'Fecha fin prevista',
    'Actual End Date' => 'Fecha fin real',
    'Status'=>'Estado',
    'Type'=>'Tipo',
    'Target Budget'=>'Presupuesto Inicial',
    'Project Url'=>'URL Proyecto',
    'Priority'=>'Prioridad Proyecto',
    'Progress'=>'Progreso',
    'Related To' => 'Relacionado con',
    'administrative' => 'administrativo',
    'operative' => 'operativo',
    'other' => 'otro',
    'low' => 'baja',
    'normal' => 'normal',
    'high' => 'alta',
    'prospecting' => 'Buscando',
    'in progress' => 'En progreso',
    'initiated' => 'Iniciado',
    'on hold' => 'En espera',
    'archived' => 'Archivado',
    'completed' => 'Finalizado',
    'delivered'=>'Entregado',
    'Created Time' => 'Fecha Creación',
    'Modified Time' => 'Fecha Modificación',
    'Description' => 'Descripción',
    'description' => 'Descripción',
    '--none--' => '--ninguno--',
    'Deadline' => 'Entrega',
    'Operation' => 'Actividad',
    'Project Name' => 'Nombre Proyecto',
    'LBL_RELATED_PROJECT_TASKS' => 'Actividades',
    'LBL_RELATED_PROJECT_MILESTONES' => 'Hitos',

	'Charts' => 'Gráficos',
	'LBL_PROGRESS_CHART' => 'Gráfico Progreso',
	'Project No' => 'Nº Proyecto',

	'Project Milestones' => 'Hitos Proyecto',
	'Project Tasks' => 'Actividades Proyecto',
	'Project Team' => 'Equipo Proyecto',
	'Project ID' => 'Id Proyecto',
);

?>
